@@ -1,5 +1,5 @@
 package Moose::Meta::TypeConstraint::Enum;
-our $VERSION = '2.2012';
+our $VERSION = '2.2200';
 
 use strict;
 use warnings;
@@ -72,6 +72,15 @@ sub new {
     $self->compile_type_constraint()
         unless $self->_has_compiled_type_constraint;
 
+    $self->message( sub {
+        my $value = shift;
+        sprintf(
+            '%s. Value must be equal to %s.',
+            $self->_default_message->( $value ),
+            Moose::Util::_english_list_or( map B::perlstring($_), @{ $self->values } ),
+        )
+    } );
+
     return $self;
 }
 
@@ -126,7 +135,7 @@ Moose::Meta::TypeConstraint::Enum - Type constraint for enumerated values.
 
 =head1 VERSION
 
-version 2.2012
+version 2.2200
 
 =head1 DESCRIPTION
 
@@ -176,7 +185,7 @@ See L<Moose/BUGS> for details on reporting bugs.
 
 =item *
 
-Stevan Little <stevan.little@iinteractive.com>
+Stevan Little <stevan@cpan.org>
 
 =item *
 
@@ -184,11 +193,11 @@ Dave Rolsky <autarch@urth.org>
 
 =item *
 
-Jesse Luehrs <doy@tozt.net>
+Jesse Luehrs <doy@cpan.org>
 
 =item *
 
-Shawn M Moore <code@sartak.org>
+Shawn M Moore <sartak@cpan.org>
 
 =item *
 
@@ -204,7 +213,7 @@ Florian Ragwitz <rafl@debian.org>
 
 =item *
 
-Hans Dieter Pearcey <hdp@weftsoar.net>
+Hans Dieter Pearcey <hdp@cpan.org>
 
 =item *
 
@@ -212,7 +221,7 @@ Chris Prather <chris@prather.org>
 
 =item *
 
-Matt S Trout <mst@shadowcat.co.uk>
+Matt S Trout <mstrout@cpan.org>
 
 =back
 
